# Data types

## Generic

Package `datamaestro.data`

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.Base
```

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.Generic
```

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.File
```



## CSV data

Package `datamaestro.data.csv`

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.csv.Generic
```

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.csv.Matrix
```


## Machine Learning

Package `datamaestro.data.ml`

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.ml.Supervised
```

## Tensor

Package `datamaestro.data.tensor`

```{eval-rst}
.. autoxpmconfig:: datamaestro.data.tensor.IDX
```
